/**********************************************************************
 *
 * extlinkaction.cpp -- 
 * Copyright (C) 1999  The New Zealand Digital Library Project
 *
 * A component of the Greenstone digital library software
 * from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *********************************************************************/


#include <string.h>
#include "extlinkaction.h"
#include "cgiutils.h"

extlinkaction::extlinkaction () {

  // this action uses cgi variables "a", "d", and "href"

  cgiarginfo arg_ainfo;
  arg_ainfo.shortname = "a";
  arg_ainfo.longname = "action";
  arg_ainfo.multiplechar = true;
  arg_ainfo.defaultstatus = cgiarginfo::weak;
  arg_ainfo.argdefault = "extlink";
  arg_ainfo.savedarginfo = cgiarginfo::must;
  argsinfo.addarginfo (NULL, arg_ainfo);

  arg_ainfo.shortname = "el";
  arg_ainfo.longname = "external link preference";
  arg_ainfo.multiplechar = true;
  arg_ainfo.defaultstatus = cgiarginfo::weak;
  arg_ainfo.argdefault = "prompt";
  arg_ainfo.savedarginfo = cgiarginfo::must;
  argsinfo.addarginfo (NULL, arg_ainfo);

  arg_ainfo.shortname = "d";
  arg_ainfo.longname = "document OID";
  arg_ainfo.multiplechar = true;
  arg_ainfo.defaultstatus = cgiarginfo::none;
  arg_ainfo.argdefault = "";
  arg_ainfo.savedarginfo = cgiarginfo::can;
  argsinfo.addarginfo (NULL, arg_ainfo);

  arg_ainfo.shortname = "href";
  arg_ainfo.longname = "URL of external link";
  arg_ainfo.multiplechar = true;
  arg_ainfo.defaultstatus = cgiarginfo::none;
  arg_ainfo.argdefault = "";
  arg_ainfo.savedarginfo = cgiarginfo::can;
  argsinfo.addarginfo (NULL, arg_ainfo);

  arg_ainfo.shortname = "rl";
  arg_ainfo.longname = "is relative link";
  arg_ainfo.multiplechar = false;
  arg_ainfo.defaultstatus = cgiarginfo::none;
  arg_ainfo.argdefault = "0";
  arg_ainfo.savedarginfo = cgiarginfo::mustnot;
  argsinfo.addarginfo (NULL, arg_ainfo);

}

extlinkaction::~extlinkaction () {
}



void extlinkaction::get_cgihead_info (cgiargsclass &args, recptprotolistclass * /*protos*/,
				      response_t &response, text_t &response_data, 
				      ostream &/*logout*/) 
{
  if (args["el"] == "direct")
    {
      response = location;
      response_data =  args["href"];
    }
  else
    {
      response = content;
      response_data = "text/html";
    }
}



void extlinkaction::define_internal_macros (displayclass &disp, cgiargsclass &args, 
					    recptprotolistclass * /*protos*/, 
					    ostream &/*logout*/) {
  
  // define_internal_macros sets the following macros:

  // _nexturl_             link to external page
  // _prevdoc_             link to previous document
  
  disp.setmacro("nexturl", "extlink", cgi_safe(args["href"]));
  disp.setmacro("prevdoc", "extlink", args["d"]);
}


bool extlinkaction::do_action (cgiargsclass &args, recptprotolistclass * /*protos*/, 
			       browsermapclass * /*browsers*/, displayclass &disp,
			       outconvertclass &outconvert, ostream &textout,
			       ostream &/*logout*/) {

  if (args["el"] != "direct")
    {
      if (args["href"] != "")
	{
	  textout << outconvert << disp << ("_extlink:header_\n")
		  << ("_extlink:foundcontent_\n")
		  << ("_extlink:footer_\n");
	}
      else
	{
	  textout << outconvert << disp << ("_extlink:header_\n")
		  << ("_extlink:notfoundcontent_\n")
		  << ("_extlink:footer_\n");
	}
    }

  return true;
}



